# citesdoc-110
API pro datový konektor dokumentů CITES   ### Verze 1.0.1   OrderType, CustomsPermitType, CustomsGoodsType, AttachmentType, AttachmentListType, LinkedType, DocumentAdditionalType additional a attachments  ### Verze 1.1.0 - holder_history - applicant  - stanoviska - evidenční karta (DocumentStatement*Type, DocumentRegistrationCardType)) - práce s permity v různých formátech 

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.1.0
- Package version: 1.1.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install


```sh
pip install sysnet-citesdoc110
```

Then import the package:
```python
import citesdoc_110 
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import citesdoc_110
from citesdoc_110.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key_auth
configuration = citesdoc_110.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = citesdoc_110.AdditionalApi(citesdoc_110.ApiClient(configuration))
identifier = 'identifier_example' # str | Identifikátor dokumentu (PID nebo UNID)

try:
    # Odstraní dokument (cruD)
    api_response = api_instance.delete_additional_document(identifier)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AdditionalApi->delete_additional_document: %s\n" % e)

# Configure API key authorization: api_key_auth
configuration = citesdoc_110.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = citesdoc_110.AdditionalApi(citesdoc_110.ApiClient(configuration))
identifier = 'identifier_example' # str | Identifikátor dokumentu (PID nebo UNID)

try:
    # Vrací konkrétní dodatečný dokument (cRud)
    api_response = api_instance.get_additional_document(identifier)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AdditionalApi->get_additional_document: %s\n" % e)

# Configure API key authorization: api_key_auth
configuration = citesdoc_110.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = citesdoc_110.AdditionalApi(citesdoc_110.ApiClient(configuration))
parent = 'parent_example' # str | Identifikátor nařízeného dokument (PID, UUID, UNID) (optional)
doc_code = 'doc_code_example' # str |  (optional)
creator = 'creator_example' # str | Klíčové slovo pro vyhledání dokumentu podle autora (optional)
key = 'key_example' # str | předává klíčové slovo pro vyhledání dokumentů. Lomítka nahrazovat podtržítkem (optional)
search = 'search_example' # str | předává text pro fulltextové vyhledání dokumentů (optional)
start = 56 # int | První dokument na stránce (optional)
page_size = 56 # int | Velikost stránky při stránkovaném výstupu (optional)
page = 56 # int | Číslo stránky výstupu (optional)

try:
    # Vrací seznam dodatečných dokumentů
    api_response = api_instance.get_additional_list(parent=parent, doc_code=doc_code, creator=creator, key=key, search=search, start=start, page_size=page_size, page=page)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AdditionalApi->get_additional_list: %s\n" % e)

# Configure API key authorization: api_key_auth
configuration = citesdoc_110.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = citesdoc_110.AdditionalApi(citesdoc_110.ApiClient(configuration))
identifier = 'identifier_example' # str | Identifikátor dokumentu (PID nebo UNID)

try:
    # Vrací PDF dodatečného dokumentu
    api_response = api_instance.get_pdf_file_additional(identifier)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AdditionalApi->get_pdf_file_additional: %s\n" % e)

# Configure API key authorization: api_key_auth
configuration = citesdoc_110.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = citesdoc_110.AdditionalApi(citesdoc_110.ApiClient(configuration))
body = citesdoc_110.CitesDocumentAdditionalType() # CitesDocumentAdditionalType |  (optional)

try:
    # Vloží nový dodatečný dokument
    api_response = api_instance.post_additional_document(body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AdditionalApi->post_additional_document: %s\n" % e)

# Configure API key authorization: api_key_auth
configuration = citesdoc_110.Configuration()
configuration.api_key['X-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-API-KEY'] = 'Bearer'

# create an instance of the API class
api_instance = citesdoc_110.AdditionalApi(citesdoc_110.ApiClient(configuration))
identifier = 'identifier_example' # str | Identifikátor dokumentu (PID nebo UNID)
body = citesdoc_110.CitesDocumentAdditionalType() # CitesDocumentAdditionalType |  (optional)

try:
    # Aktualizuje dodatečný dokument (crUd)
    api_response = api_instance.put_additional_document(identifier, body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AdditionalApi->put_additional_document: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://athos.sysnet.cz/citesdoc/1.1.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdditionalApi* | [**delete_additional_document**](docs/AdditionalApi.md#delete_additional_document) | **DELETE** /additional/{identifier} | Odstraní dokument (cruD)
*AdditionalApi* | [**get_additional_document**](docs/AdditionalApi.md#get_additional_document) | **GET** /additional/{identifier} | Vrací konkrétní dodatečný dokument (cRud)
*AdditionalApi* | [**get_additional_list**](docs/AdditionalApi.md#get_additional_list) | **GET** /additional | Vrací seznam dodatečných dokumentů
*AdditionalApi* | [**get_pdf_file_additional**](docs/AdditionalApi.md#get_pdf_file_additional) | **GET** /additional/pdf/{identifier} | Vrací PDF dodatečného dokumentu
*AdditionalApi* | [**post_additional_document**](docs/AdditionalApi.md#post_additional_document) | **POST** /additional | Vloží nový dodatečný dokument
*AdditionalApi* | [**put_additional_document**](docs/AdditionalApi.md#put_additional_document) | **PUT** /additional/{identifier} | Aktualizuje dodatečný dokument (crUd)
*AdminsApi* | [**delete_template**](docs/AdminsApi.md#delete_template) | **DELETE** /template/{doc_code} | Odstraní položku šablony PDF včetně všech souborů (cruD)
*AdminsApi* | [**get_template**](docs/AdminsApi.md#get_template) | **GET** /template/{doc_code} | Vrátí popis šablony (cRud)
*AdminsApi* | [**get_template_list**](docs/AdminsApi.md#get_template_list) | **GET** /template | Vrací seznam šablon
*AdminsApi* | [**post_template_item**](docs/AdminsApi.md#post_template_item) | **POST** /template | Zavede novou položku šablony (Crud)
*AdminsApi* | [**put_template**](docs/AdminsApi.md#put_template) | **PUT** /template/{doc_code} | Aktualizuje popis šablony (crUd)
*AdminsApi* | [**upload_template_file_binary**](docs/AdminsApi.md#upload_template_file_binary) | **PUT** /template/upload/binary/{doc_code} | Nahraje soubor se šablonou jiný formát (nař. zip))
*AdminsApi* | [**upload_template_file_pdf**](docs/AdminsApi.md#upload_template_file_pdf) | **PUT** /template/upload/pdf/{doc_code} | Nahraje soubor se šablonou PDF
*AdminsApi* | [**upload_template_file_xml**](docs/AdminsApi.md#upload_template_file_xml) | **PUT** /template/upload/xml/{doc_code} | Nahraje soubor se šablonou XML
*AttachmentsApi* | [**delete_attachment**](docs/AttachmentsApi.md#delete_attachment) | **DELETE** /attachment/{identifier} | odstraní přílohu i s metadaty
*AttachmentsApi* | [**get_attachment**](docs/AttachmentsApi.md#get_attachment) | **GET** /attachment/download/{identifier} | vrací soubor přílohy
*AttachmentsApi* | [**get_attachment_list**](docs/AttachmentsApi.md#get_attachment_list) | **GET** /attachment | získá seznam příloh
*AttachmentsApi* | [**get_attachment_list_container**](docs/AttachmentsApi.md#get_attachment_list_container) | **GET** /atachment/container/{container} | vrací seznam příloh v kontejneru
*AttachmentsApi* | [**get_attachment_list_document**](docs/AttachmentsApi.md#get_attachment_list_document) | **GET** /atachment/document/{document} | vrací seznam příloh v dokumentu
*AttachmentsApi* | [**get_attachment_metadata**](docs/AttachmentsApi.md#get_attachment_metadata) | **GET** /attachment/{identifier} | vrací metadata přílohy
*AttachmentsApi* | [**post_attachment**](docs/AttachmentsApi.md#post_attachment) | **POST** /attachment | uploaduje novou přílohu (Crud)
*AttachmentsApi* | [**put_attachment**](docs/AttachmentsApi.md#put_attachment) | **PUT** /attachment/{identifier} | aktualizuje metadata přílohy
*DevelopersApi* | [**info_api**](docs/DevelopersApi.md#info_api) | **GET** /info | Vrací servisní informace
*DevelopersApi* | [**info_api_head**](docs/DevelopersApi.md#info_api_head) | **HEAD** /info | Vrací informaci o dostupnosti služby
*PermitApi* | [**convert_permit_cz2_doc**](docs/PermitApi.md#convert_permit_cz2_doc) | **POST** /convert/cz/doc | Konvertuje permit z formátu CZ do produkčního formátu CITES
*PermitApi* | [**convert_permit_cz2_eu**](docs/PermitApi.md#convert_permit_cz2_eu) | **POST** /convert/cz/eu | Konvertuje permit z formátu CZ do EU
*PermitApi* | [**convert_permit_doc2_cz**](docs/PermitApi.md#convert_permit_doc2_cz) | **POST** /convert/doc/cz | Konvertuje permit z produkčního formátu CITES do formátu CZ
*PermitApi* | [**convert_permit_doc2_eu**](docs/PermitApi.md#convert_permit_doc2_eu) | **POST** /convert/doc/eu | Konvertuje permit z produkčního formátu CITES do formátu EU
*PermitApi* | [**convert_permit_eu2_cz**](docs/PermitApi.md#convert_permit_eu2_cz) | **POST** /convert/eu/cz | Konvertuje permit z formátu EU do CZ
*PermitApi* | [**convert_permit_eu2_doc**](docs/PermitApi.md#convert_permit_eu2_doc) | **POST** /convert/eu/doc | Konvertuje permit z formátu EU do produkčního formátu CITES
*PermitApi* | [**get_permit_cz**](docs/PermitApi.md#get_permit_cz) | **GET** /permit/cz/{idno} | Vrací permit v CZ CITES formátu
*PermitApi* | [**get_permit_doc**](docs/PermitApi.md#get_permit_doc) | **GET** /permit/doc/{idno} | Vrací permit v produkčním CITES formátu
*PermitApi* | [**get_permit_eu**](docs/PermitApi.md#get_permit_eu) | **GET** /permit/eu/{idno} | Vrací permit v EU CITES formátu
*PermitApi* | [**post_permit_cz**](docs/PermitApi.md#post_permit_cz) | **POST** /permit/cz/{idno} | Nahraje permit ve formátu EU
*PermitApi* | [**post_permit_doc**](docs/PermitApi.md#post_permit_doc) | **POST** /permit/doc/{idno} | Nahraje permit v produkčním formátu CITES
*PermitApi* | [**post_permit_eu**](docs/PermitApi.md#post_permit_eu) | **POST** /permit/eu/{idno} | Nahraje permit ve formátu EU
*PermitApi* | [**put_permit_cz**](docs/PermitApi.md#put_permit_cz) | **PUT** /permit/cz/{idno} | Aktualizuje permit ve formátu EU
*PermitApi* | [**put_permit_doc**](docs/PermitApi.md#put_permit_doc) | **PUT** /permit/doc/{idno} | Aktualizuje permit v produkčním formátu CITES
*PermitApi* | [**put_permit_eu**](docs/PermitApi.md#put_permit_eu) | **PUT** /permit/eu/{idno} | Aktualizuje permit ve formátu EU
*PublicApi* | [**delete_document**](docs/PublicApi.md#delete_document) | **DELETE** /doc/{identifier} | Odstraní dokument (cruD)
*PublicApi* | [**get_document**](docs/PublicApi.md#get_document) | **GET** /doc/{identifier} | Vrací konkrétní dokument (cRud)
*PublicApi* | [**get_document_list**](docs/PublicApi.md#get_document_list) | **GET** /doc | Vrací seznam dokumentů podle klíče nebo kódu
*PublicApi* | [**get_pdf_file**](docs/PublicApi.md#get_pdf_file) | **GET** /doc/pdf/{identifier} | Vrací PDF dokument
*PublicApi* | [**post_document**](docs/PublicApi.md#post_document) | **POST** /doc | Vytvoří nový dokument (Crud)
*PublicApi* | [**put_document**](docs/PublicApi.md#put_document) | **PUT** /doc/{identifier} | Aktualizuje dokument (crUd)
*RegistrationCardsApi* | [**delete_registration_card**](docs/RegistrationCardsApi.md#delete_registration_card) | **DELETE** /registration_card/{identifier} | Odstraní evidenční kartu (cruD)
*RegistrationCardsApi* | [**get_pdf_file_registration_card**](docs/RegistrationCardsApi.md#get_pdf_file_registration_card) | **GET** /registration_card/pdf/{identifier} | Vrací PDF dokument
*RegistrationCardsApi* | [**get_registration_card**](docs/RegistrationCardsApi.md#get_registration_card) | **GET** /registration_card/{identifier} | Vrací konkrétní evidenční kartu (cRud)
*RegistrationCardsApi* | [**get_registration_card_list**](docs/RegistrationCardsApi.md#get_registration_card_list) | **GET** /registration_card | Vrací seznam evidenčních karet
*RegistrationCardsApi* | [**post_registration_card**](docs/RegistrationCardsApi.md#post_registration_card) | **POST** /registration_card | Vytvoří novou evidenční kartu (Crud)
*RegistrationCardsApi* | [**put_registration_card**](docs/RegistrationCardsApi.md#put_registration_card) | **PUT** /registration_card/{identifier} | Aktualizuje evidenční kartu (crUd)
*StatementApi* | [**delete_statement**](docs/StatementApi.md#delete_statement) | **DELETE** /statement/{identifier} | Odstraní stanovisko AOPK (cruD)
*StatementApi* | [**delete_statement_request**](docs/StatementApi.md#delete_statement_request) | **DELETE** /request/{identifier} | Odstraní žádost o stanovisko AOPK (cruD)
*StatementApi* | [**get_pdf_file_statement**](docs/StatementApi.md#get_pdf_file_statement) | **GET** /statement/pdf/{identifier} | Vrací PDF dokument
*StatementApi* | [**get_statement_certificate**](docs/StatementApi.md#get_statement_certificate) | **GET** /statement/certificate/{identifier} | Vrací konkrétní stanovisko AOPK k výjimce (cRud)
*StatementApi* | [**get_statement_certificate_request**](docs/StatementApi.md#get_statement_certificate_request) | **GET** /request/certificate/{identifier} | Vrací konkrétní žádost o stanovisko AOPK k výjimce (cRud)
*StatementApi* | [**get_statement_list**](docs/StatementApi.md#get_statement_list) | **GET** /statement | Vrací seznam stanovisek AOPK podle klíče nebo kódu
*StatementApi* | [**get_statement_permit**](docs/StatementApi.md#get_statement_permit) | **GET** /statement/permit/{identifier} | Vrací konkrétní stanovisko AOPK k permitu (cRud)
*StatementApi* | [**get_statement_request_list**](docs/StatementApi.md#get_statement_request_list) | **GET** /request | Vrací seznam žádostí o stanoviska AOPK podle klíče nebo kódu
*StatementApi* | [**post_statement_certificate**](docs/StatementApi.md#post_statement_certificate) | **POST** /statement/certificate | Vytvoří nové stanovisko AOPK k potvrzení o výjimce (Crud)
*StatementApi* | [**post_statement_permit**](docs/StatementApi.md#post_statement_permit) | **POST** /statement/permit | Vytvoří nové stanovisko AOPK k permitu (Crud)
*StatementApi* | [**post_statement_request_certificate**](docs/StatementApi.md#post_statement_request_certificate) | **POST** /request/certificate | Vytvoří novou žádost o stanovisko AOPK k potvrzení o výjimce (Crud)
*StatementApi* | [**put_statement_certificate**](docs/StatementApi.md#put_statement_certificate) | **PUT** /statement/certificate/{identifier} | Aktualizuje stanovisko AOPK k výjimce (crUd)
*StatementApi* | [**put_statement_certificate_request**](docs/StatementApi.md#put_statement_certificate_request) | **PUT** /request/certificate/{identifier} | Aktualizuje žádost o stanovisko AOPK k výjimce (crUd)
*StatementApi* | [**put_statement_permit**](docs/StatementApi.md#put_statement_permit) | **PUT** /statement/permit/{identifier} | Aktualizuje stanovisko AOPK k permitu (crUd)

## Documentation For Models

 - [AdditionalEntryType](docs/AdditionalEntryType.md)
 - [AgreeType](docs/AgreeType.md)
 - [AuthoritativeSignatoryPersonType](docs/AuthoritativeSignatoryPersonType.md)
 - [BaseEntryListType](docs/BaseEntryListType.md)
 - [CITESEPermitType](docs/CITESEPermitType.md)
 - [CZCitesPermitType](docs/CZCitesPermitType.md)
 - [CitesDocumentAdditionalEntryListType](docs/CitesDocumentAdditionalEntryListType.md)
 - [CitesDocumentAdditionalType](docs/CitesDocumentAdditionalType.md)
 - [CitesDocumentAttachmentListType](docs/CitesDocumentAttachmentListType.md)
 - [CitesDocumentAttachmentType](docs/CitesDocumentAttachmentType.md)
 - [CitesDocumentEntryListType](docs/CitesDocumentEntryListType.md)
 - [CitesDocumentPrincipalType](docs/CitesDocumentPrincipalType.md)
 - [CitesDocumentRegistrationCardType](docs/CitesDocumentRegistrationCardType.md)
 - [CitesDocumentStatementCertificateRequestType](docs/CitesDocumentStatementCertificateRequestType.md)
 - [CitesDocumentStatementCertificateType](docs/CitesDocumentStatementCertificateType.md)
 - [CitesDocumentStatementPermitType](docs/CitesDocumentStatementPermitType.md)
 - [CitesDocumentTemplateType](docs/CitesDocumentTemplateType.md)
 - [CitesDocumentXfdfListType](docs/CitesDocumentXfdfListType.md)
 - [CitesDocumentXfdfType](docs/CitesDocumentXfdfType.md)
 - [CitesDocumentXfdfTypeIdentifier](docs/CitesDocumentXfdfTypeIdentifier.md)
 - [CitesDocumentXfdfTypeTemplateFile](docs/CitesDocumentXfdfTypeTemplateFile.md)
 - [CodeType](docs/CodeType.md)
 - [ConditionsType](docs/ConditionsType.md)
 - [CountryIDType](docs/CountryIDType.md)
 - [CrossBorderRegulatoryProcedureType](docs/CrossBorderRegulatoryProcedureType.md)
 - [CustomsGoodsType](docs/CustomsGoodsType.md)
 - [CustomsPermitType](docs/CustomsPermitType.md)
 - [DocumentAuthenticationType](docs/DocumentAuthenticationType.md)
 - [DocumentCodeType](docs/DocumentCodeType.md)
 - [DocumentContextParameterType](docs/DocumentContextParameterType.md)
 - [DocumentPrincipalCustomsGoodsType](docs/DocumentPrincipalCustomsGoodsType.md)
 - [DocumentPrincipalCustomsPermitType](docs/DocumentPrincipalCustomsPermitType.md)
 - [DocumentVersionType](docs/DocumentVersionType.md)
 - [EntryType](docs/EntryType.md)
 - [ErrorModel](docs/ErrorModel.md)
 - [ExchangedDocumentContextType](docs/ExchangedDocumentContextType.md)
 - [ExchangedDocumentType](docs/ExchangedDocumentType.md)
 - [GeneralType](docs/GeneralType.md)
 - [GoodsBirthType](docs/GoodsBirthType.md)
 - [GoodsIdetificationHistoryItemType](docs/GoodsIdetificationHistoryItemType.md)
 - [GoodsIdetificationType](docs/GoodsIdetificationType.md)
 - [GoodsItemBaseType](docs/GoodsItemBaseType.md)
 - [GoodsOrderType](docs/GoodsOrderType.md)
 - [GoodsPrincipalType](docs/GoodsPrincipalType.md)
 - [GoodsQuantityType](docs/GoodsQuantityType.md)
 - [GoodsType](docs/GoodsType.md)
 - [GoodsTypeCodeType](docs/GoodsTypeCodeType.md)
 - [GoodsTypeExtensionCodeType](docs/GoodsTypeExtensionCodeType.md)
 - [GovernmentActionCodeType](docs/GovernmentActionCodeType.md)
 - [IDType](docs/IDType.md)
 - [IssuingType](docs/IssuingType.md)
 - [LinkedListType](docs/LinkedListType.md)
 - [LinkedType](docs/LinkedType.md)
 - [LogisticsLocationType](docs/LogisticsLocationType.md)
 - [LogisticsPackageType](docs/LogisticsPackageType.md)
 - [LogisticsShippingMarksType](docs/LogisticsShippingMarksType.md)
 - [MailAddressType](docs/MailAddressType.md)
 - [MessageFunctionCodeType](docs/MessageFunctionCodeType.md)
 - [MetadataType](docs/MetadataType.md)
 - [OrderType](docs/OrderType.md)
 - [OtherType](docs/OtherType.md)
 - [PermitConditionsType](docs/PermitConditionsType.md)
 - [PermitSpecialConditionsType](docs/PermitSpecialConditionsType.md)
 - [PersonBaseType](docs/PersonBaseType.md)
 - [PersonExtendedType](docs/PersonExtendedType.md)
 - [PersonHistoryItemType](docs/PersonHistoryItemType.md)
 - [PersonType](docs/PersonType.md)
 - [PhoneNumberType](docs/PhoneNumberType.md)
 - [QuantityType](docs/QuantityType.md)
 - [ReferencedDocumentType](docs/ReferencedDocumentType.md)
 - [RelatedType](docs/RelatedType.md)
 - [RepresentativePersonType](docs/RepresentativePersonType.md)
 - [SingleWindowType](docs/SingleWindowType.md)
 - [SpecifiedPeriodType](docs/SpecifiedPeriodType.md)
 - [StatementCertificateRequestItemParentType](docs/StatementCertificateRequestItemParentType.md)
 - [StatementCertificateRequestItemType](docs/StatementCertificateRequestItemType.md)
 - [StatementCertificateRequestType](docs/StatementCertificateRequestType.md)
 - [StatementCertificateType](docs/StatementCertificateType.md)
 - [StatementDocumentType](docs/StatementDocumentType.md)
 - [StatementPermitType](docs/StatementPermitType.md)
 - [SupplyChainConsignmentItemType](docs/SupplyChainConsignmentItemType.md)
 - [SupplyChainConsignmentType](docs/SupplyChainConsignmentType.md)
 - [SupplyChainTradeLineItemType](docs/SupplyChainTradeLineItemType.md)
 - [TaxonItemType](docs/TaxonItemType.md)
 - [TextType](docs/TextType.md)
 - [TradeAddressType](docs/TradeAddressType.md)
 - [TradeCountryType](docs/TradeCountryType.md)
 - [TradePartyType](docs/TradePartyType.md)
 - [TradeProductType](docs/TradeProductType.md)
 - [TransactionType](docs/TransactionType.md)
 - [TransportEventType](docs/TransportEventType.md)
 - [TransportType](docs/TransportType.md)
 - [UserType](docs/UserType.md)
 - [WorkflowListType](docs/WorkflowListType.md)
 - [WorkflowType](docs/WorkflowType.md)
 - [XfdfFieldType](docs/XfdfFieldType.md)

## Documentation For Authorization


## api_key_auth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

info@sysnet.cz
